@@ -29,10 +29,10 @@ def write_pgpass(conn_dict,logger):
     logger.info('~write_pgpass()')
     return pgpass_path
 
-def get_connect_dict(config_path, config_section):
+def get_connect_dict(config_path, ini_section):
     config = configparser.ConfigParser()
     config.read(config_path)
-    connect_dict = dict(config['DEFAULT'])
+    connect_dict = dict(config[ini_section])
     return connect_dict
 
 def allow_create_fail(sql_path, logger):
@@ -80,8 +80,8 @@ def main():
 
     #get postgres creds
     postgres_creds_path = args.postgres_creds_path
-    kwargs = {'db_cred_path': postgres_creds_path,
-               'ini_section': ini_section, 'logger': logger}
+    kwargs = {'config_path': postgres_creds_path,
+              'ini_section': ini_section}
     conn_dict = get_connect_dict(**kwargs)
     pgpass_path = write_pgpass(conn_dict,logger)
 
